Playground help is available for the general topics listed below. In
addition, if you pass info() a function/object from the playground,
it will attempt to display guidance on an appropriate topic. For
example, `info(uniform)`. Keep in mind you can also use Python's
built-in help to get usage documentation on any function, like
`help(uniform)`, though you should probably try `info` first.

General Topics
--------------
+ overview
+ SOON kinds
+ SOON frps
+ SOON statistics
+ SOON utilities
+ ...ATTN
